@@ -6,9 +6,9 @@ Type annotations for fis service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_fis.literals import ExperimentActionStatus
+    from mypy_boto3_fis.literals import ExperimentActionStatusType
 
-    data: ExperimentActionStatus = "cancelled"
+    data: ExperimentActionStatusType = "cancelled"
     ```
 """
 import sys
@@ -19,12 +19,12 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("ExperimentActionStatus", "ExperimentStatus")
+__all__ = ("ExperimentActionStatusType", "ExperimentStatusType")
 
 
-ExperimentActionStatus = Literal[
+ExperimentActionStatusType = Literal[
     "cancelled", "completed", "failed", "initiating", "pending", "running", "stopped", "stopping"
 ]
-ExperimentStatus = Literal[
+ExperimentStatusType = Literal[
     "completed", "failed", "initiating", "pending", "running", "stopped", "stopping"
 ]
